gchecky.model.merchant_calculation_results_t

Package gchecky :: Module model :: Class merchant_calculation_results_t |
[hide private]
[frames] | no frames]

# Class merchant_calculation_results_t

source code

    object --+
             |
     gxml.Node --+
                 |
     gxml.Document --+
                     |
                    merchant_calculation_results_t

Nested Classes | [hide private]
Inherited from `gxml.Document`: `__metaclass__`

Instance Methods | [hide private]
Inherited from `gxml.Document`: `__str__`, `toxml` Inherited from `gxml.Node`: `__eq__`, `__init__`, `__neq__`, `read`, `write` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`

Class Methods | [hide private]
Inherited from `gxml.Document`: `fromxml` Inherited from `gxml.Node`: `fields`, `set_fields`

Static Methods | [hide private]
Inherited from `gxml.Node`: `__new__`

Class Variables | [hide private]
| tag_name = ``'``merchant-calculation-results``'`` The document's unique xml tag name.
| results = `List:PATH(results):RE`...``
| _fields = ``{``'``results``'``:` List:PATH(results):RE`...`` list of meta-Fields of this class.

Properties | [hide private]
Inherited from `object`: `__class__`

Class Variable Details | [hide private]

  ### results Value:
      List:PATH(results):REQ:[
          Node:PATH(result):REQ:{ result_t }
      ]

  ### _fields list of meta-Fields of this class. Value:
      {'results': List:PATH(results):REQ:[
          Node:PATH(result):REQ:{ result_t }
      ]}